@@ -19,6 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <string.h>
 
 #include "pango-glyph-item-private.h"
@@ -47,7 +48,7 @@ typedef struct _LineIter       LineIter;
  * us to use a gap position at x=line_width and still have it be part of
  * of a run.
  *
- * We grow the grap out one "span" at a time, where a span is simply a
+ * We grow the gap out one "span" at a time, where a span is simply a
  * consecutive run of clusters that we can't interrupt with an ellipsis.
  *
  * When choosing whether to grow the gap at the start or the end, we
@@ -84,11 +85,11 @@ struct _EllipsizeState
   RunInfo *run_info;		/* Array of information about each run */
   int n_runs;
 
-  int total_width;		/* Original width of line in pango units */
+  int total_width;		/* Original width of line in Pango units */
   int gap_center;		/* Goal for center of gap */
   
   PangoGlyphItem *ellipsis_run;	/* Run created to hold ellipsis */
-  int ellipsis_width;		/* Width of ellipsis, in pango units */
+  int ellipsis_width;		/* Width of ellipsis, in Pango units */
   int ellipsis_is_cjk;		/* Whether the first character in the ellipsized
 				 * is wide; this triggers us to try to use a
 				 * mid-line ellipsis instead of a baseline
@@ -97,12 +98,12 @@ struct _EllipsizeState
   PangoAttrIterator *line_start_attr; /* Cached PangoAttrIterator for the start of the run */
   
   LineIter gap_start_iter;	/* Iteratator pointig to the first cluster in gap */
-  int gap_start_x;		/* x position of start of gap, in pango units */
+  int gap_start_x;		/* x position of start of gap, in Pango units */
   PangoAttrIterator *gap_start_attr; /* Attribute iterator pointing to a range containing
 				      * the first character in gap */
   
   LineIter gap_end_iter;	/* Iterator pointing to last cluster in gap */
-  int gap_end_x;		/* x position of end of gap, in pango units */
+  int gap_end_x;		/* x position of end of gap, in Pango units */
 };
 
 /* Compute global information needed for the itemization process
@@ -125,7 +126,6 @@ init_state (EllipsizeState  *state,
   start_offset = g_utf8_strlen (line->layout->text,
 				line->start_index);
 
-  start_offset = 0;
   state->total_width = 0;
   for (l = line->runs, i = 0; l; l = l->next, i++)
     {
@@ -174,12 +174,12 @@ get_cluster_width (LineIter *iter)
   if (run_iter->start_glyph < run_iter->end_glyph) /* LTR */
     {
       for (i = run_iter->start_glyph; i < run_iter->end_glyph; i++)
-	width += glyphs->glyphs[run_iter->start_glyph].geometry.width;
+	width += glyphs->glyphs[i].geometry.width;
     }
   else			                 /* RTL */
     {
       for (i = run_iter->start_glyph; i > run_iter->end_glyph; i--)
-	width += glyphs->glyphs[run_iter->start_glyph].geometry.width;
+	width += glyphs->glyphs[i].geometry.width;
     }
 
   return width;
@@ -236,7 +236,7 @@ line_iter_prev_cluster (EllipsizeState *state,
  * - Starts a grapheme - checked here
  *
  * In the future we'd also like to add a check for cursive connectivity here.
- * This should be an addition to PangoGlyphVisAttr
+ * This should be an addition to #PangoGlyphVisAttr
  *
  */
 
@@ -306,7 +306,7 @@ shape_ellipsis (EllipsizeState *state)
    */
   if (!state->ellipsis_run)
     {
-      state->ellipsis_run = g_new (PangoGlyphItem, 1);
+      state->ellipsis_run = g_slice_new (PangoGlyphItem);
       state->ellipsis_run->glyphs = pango_glyph_string_new ();
       state->ellipsis_run->item = NULL;
     }
@@ -386,14 +386,13 @@ advance_iterator_to (PangoAttrIterator *iter,
 {
   int start, end;
   
-  while (TRUE)
+  do
     {
       pango_attr_iterator_range (iter, &start, &end);
       if (end > new_index)
 	break;
-      
-      pango_attr_iterator_next (iter);
     }
+  while (pango_attr_iterator_next (iter));
 }
 
 /* Updates the shaping of the ellipsis if necessary when we move the
@@ -565,6 +564,7 @@ remove_one_span (EllipsizeState *state)
   LineIter new_gap_end_iter;
   int new_gap_start_x;
   int new_gap_end_x;
+  int width;
 
   /* Find one span backwards and forward from the gap
    */
@@ -574,9 +574,11 @@ remove_one_span (EllipsizeState *state)
     {
       if (!line_iter_prev_cluster (state, &new_gap_start_iter))
 	break;
-      new_gap_start_x -= get_cluster_width (&new_gap_start_iter);
+      width = get_cluster_width (&new_gap_start_iter);
+      new_gap_start_x -= width;
     }
-  while (!starts_at_ellipsization_boundary (state, &new_gap_start_iter));
+  while (!starts_at_ellipsization_boundary (state, &new_gap_start_iter) ||
+	 width == 0);
 
   new_gap_end_iter = state->gap_end_iter;
   new_gap_end_x = state->gap_end_x;
@@ -584,9 +586,11 @@ remove_one_span (EllipsizeState *state)
     {
       if (!line_iter_next_cluster (state, &new_gap_end_iter))
 	break;
-      new_gap_end_x += get_cluster_width (&new_gap_end_iter);
+      width = get_cluster_width (&new_gap_end_iter);
+      new_gap_end_x += width;
     }
-  while (!ends_at_ellipsization_boundary (state, &new_gap_end_iter));
+  while (!ends_at_ellipsization_boundary (state, &new_gap_end_iter) ||
+	 width == 0);
 
   if (state->gap_end_x == new_gap_end_x && state->gap_start_x == new_gap_start_x)
     return FALSE;
@@ -716,7 +720,7 @@ current_width (EllipsizeState *state)
  * @line: a #PangoLayoutLine
  * @attrs: Attributes being used for itemization/shaping
  * 
- * Given a PangoLayoutLine with the runs still in logical order, ellipsize
+ * Given a #PangoLayoutLine with the runs still in logical order, ellipsize
  * it according the layout's policy to fit within the set width of the layout.
  **/
 void
@@ -724,6 +728,7 @@ _pango_layout_line_ellipsize (PangoLayoutLine *line,
 			      PangoAttrList   *attrs)
 {
   EllipsizeState state;
+  int goal_width;
 
   if (line->layout->ellipsize == PANGO_ELLIPSIZE_NONE ||
       line->layout->width < 0)
@@ -731,12 +736,16 @@ _pango_layout_line_ellipsize (PangoLayoutLine *line,
 
   init_state (&state, line, attrs);
 
-  if (state.total_width <= state.layout->width)
+  goal_width = state.layout->width;
+  if (state.layout->indent > 0 && state.layout->alignment != PANGO_ALIGN_CENTER)
+    goal_width -= state.layout->indent;
+
+  if (state.total_width <= goal_width)
     goto out;
 
   find_initial_span (&state);
 
-  while (current_width (&state) > state.layout->width)
+  while (current_width (&state) > goal_width)
     {
       if (!remove_one_span (&state))
 	break;
