@@ -33,11 +33,10 @@ pango_attr_type_get_type (void)
       { PANGO_ATTR_ABSOLUTE_SIZE, "PANGO_ATTR_ABSOLUTE_SIZE", "absolute-size" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoAttrType", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoAttrType"), values);
   }
   return etype;
 }
-
 GType
 pango_underline_get_type (void)
 {
@@ -51,12 +50,11 @@ pango_underline_get_type (void)
       { PANGO_UNDERLINE_ERROR, "PANGO_UNDERLINE_ERROR", "error" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoUnderline", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoUnderline"), values);
   }
   return etype;
 }
 
-
 /* enumerations from "pango-coverage.h" */
 GType
 pango_coverage_level_get_type (void)
@@ -70,12 +68,11 @@ pango_coverage_level_get_type (void)
       { PANGO_COVERAGE_EXACT, "PANGO_COVERAGE_EXACT", "exact" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoCoverageLevel", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoCoverageLevel"), values);
   }
   return etype;
 }
 
-
 /* enumerations from "pango-font.h" */
 GType
 pango_style_get_type (void)
@@ -88,11 +85,10 @@ pango_style_get_type (void)
       { PANGO_STYLE_ITALIC, "PANGO_STYLE_ITALIC", "italic" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoStyle", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoStyle"), values);
   }
   return etype;
 }
-
 GType
 pango_variant_get_type (void)
 {
@@ -103,11 +99,10 @@ pango_variant_get_type (void)
       { PANGO_VARIANT_SMALL_CAPS, "PANGO_VARIANT_SMALL_CAPS", "small-caps" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoVariant", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoVariant"), values);
   }
   return etype;
 }
-
 GType
 pango_weight_get_type (void)
 {
@@ -123,11 +118,10 @@ pango_weight_get_type (void)
       { PANGO_WEIGHT_HEAVY, "PANGO_WEIGHT_HEAVY", "heavy" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoWeight", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoWeight"), values);
   }
   return etype;
 }
-
 GType
 pango_stretch_get_type (void)
 {
@@ -145,11 +139,10 @@ pango_stretch_get_type (void)
       { PANGO_STRETCH_ULTRA_EXPANDED, "PANGO_STRETCH_ULTRA_EXPANDED", "ultra-expanded" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoStretch", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoStretch"), values);
   }
   return etype;
 }
-
 GType
 pango_font_mask_get_type (void)
 {
@@ -164,12 +157,11 @@ pango_font_mask_get_type (void)
       { PANGO_FONT_MASK_SIZE, "PANGO_FONT_MASK_SIZE", "size" },
       { 0, NULL, NULL }
     };
-    etype = g_flags_register_static ("PangoFontMask", values);
+    etype = g_flags_register_static (g_intern_static_string ("PangoFontMask"), values);
   }
   return etype;
 }
 
-
 /* enumerations from "pango-layout.h" */
 GType
 pango_alignment_get_type (void)
@@ -182,11 +174,10 @@ pango_alignment_get_type (void)
       { PANGO_ALIGN_RIGHT, "PANGO_ALIGN_RIGHT", "right" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoAlignment", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoAlignment"), values);
   }
   return etype;
 }
-
 GType
 pango_wrap_mode_get_type (void)
 {
@@ -198,11 +189,10 @@ pango_wrap_mode_get_type (void)
       { PANGO_WRAP_WORD_CHAR, "PANGO_WRAP_WORD_CHAR", "word-char" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoWrapMode", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoWrapMode"), values);
   }
   return etype;
 }
-
 GType
 pango_ellipsize_mode_get_type (void)
 {
@@ -215,12 +205,11 @@ pango_ellipsize_mode_get_type (void)
       { PANGO_ELLIPSIZE_END, "PANGO_ELLIPSIZE_END", "end" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoEllipsizeMode", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoEllipsizeMode"), values);
   }
   return etype;
 }
 
-
 /* enumerations from "pango-renderer.h" */
 GType
 pango_render_part_get_type (void)
@@ -234,12 +223,11 @@ pango_render_part_get_type (void)
       { PANGO_RENDER_PART_STRIKETHROUGH, "PANGO_RENDER_PART_STRIKETHROUGH", "strikethrough" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoRenderPart", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoRenderPart"), values);
   }
   return etype;
 }
 
-
 /* enumerations from "pango-script.h" */
 GType
 pango_script_get_type (void)
@@ -309,14 +297,19 @@ pango_script_get_type (void)
       { PANGO_SCRIPT_SYLOTI_NAGRI, "PANGO_SCRIPT_SYLOTI_NAGRI", "syloti-nagri" },
       { PANGO_SCRIPT_OLD_PERSIAN, "PANGO_SCRIPT_OLD_PERSIAN", "old-persian" },
       { PANGO_SCRIPT_KHAROSHTHI, "PANGO_SCRIPT_KHAROSHTHI", "kharoshthi" },
+      { PANGO_SCRIPT_UNKNOWN, "PANGO_SCRIPT_UNKNOWN", "unknown" },
+      { PANGO_SCRIPT_BALINESE, "PANGO_SCRIPT_BALINESE", "balinese" },
+      { PANGO_SCRIPT_CUNEIFORM, "PANGO_SCRIPT_CUNEIFORM", "cuneiform" },
+      { PANGO_SCRIPT_PHOENICIAN, "PANGO_SCRIPT_PHOENICIAN", "phoenician" },
+      { PANGO_SCRIPT_PHAGS_PA, "PANGO_SCRIPT_PHAGS_PA", "phags-pa" },
+      { PANGO_SCRIPT_NKO, "PANGO_SCRIPT_NKO", "nko" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoScript", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoScript"), values);
   }
   return etype;
 }
 
-
 /* enumerations from "pango-tabs.h" */
 GType
 pango_tab_align_get_type (void)
@@ -327,12 +320,11 @@ pango_tab_align_get_type (void)
       { PANGO_TAB_LEFT, "PANGO_TAB_LEFT", "left" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoTabAlign", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoTabAlign"), values);
   }
   return etype;
 }
 
-
 /* enumerations from "pango-types.h" */
 GType
 pango_direction_get_type (void)
@@ -349,11 +341,10 @@ pango_direction_get_type (void)
       { PANGO_DIRECTION_NEUTRAL, "PANGO_DIRECTION_NEUTRAL", "neutral" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("PangoDirection", values);
+    etype = g_enum_register_static (g_intern_static_string ("PangoDirection"), values);
   }
   return etype;
 }
 
-
 /* Generated data ends here */
 
