@@ -53,6 +53,8 @@
  * or other dealings in this Software without prior written authorization
  * of the copyright holder.
  */
+
+#include <config.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -82,6 +84,33 @@ struct _PangoScriptIter
   int paren_sp;
 };
 
+#define PANGO_SCRIPT_TABLE_MIDPOINT (G_N_ELEMENTS (pango_script_table) / 2)
+
+static inline PangoScript
+pango_script_for_unichar_bsearch (gunichar ch)
+{
+  int lower = 0;
+  int upper = G_N_ELEMENTS (pango_script_table) - 1;
+  static int saved_mid = PANGO_SCRIPT_TABLE_MIDPOINT;
+  int mid = saved_mid;
+
+
+  do 
+    {
+      if (ch < pango_script_table[mid].start)
+	upper = mid - 1;
+      else if (ch >= pango_script_table[mid].start + pango_script_table[mid].chars)
+	lower = mid + 1;
+      else
+	return pango_script_table[saved_mid = mid].script;
+
+      mid = (lower + upper) / 2;
+    }
+  while (lower <= upper);
+
+  return PANGO_SCRIPT_UNKNOWN;
+}
+
 /**
  * pango_script_for_unichar:
  * @ch: a Unicode character
@@ -98,21 +127,10 @@ struct _PangoScriptIter
 PangoScript
 pango_script_for_unichar (gunichar ch)
 {
-  int lower = 0;
-  int upper = G_N_ELEMENTS (pango_script_table) - 1;
-
-  while (lower <= upper)
-    {
-      int mid = (lower + upper) / 2;
-      if (ch < pango_script_table[mid].start)
-	upper = mid - 1;
-      else if (ch >= pango_script_table[mid].start + pango_script_table[mid].chars)
-	lower = mid + 1;
-      else
-	return pango_script_table[mid].script;
-    }
-  
-  return PANGO_SCRIPT_COMMON;
+  if (ch < PANGO_EASY_SCRIPTS_RANGE)
+    return pango_script_easy_table[ch];
+  else 
+    return pango_script_for_unichar_bsearch (ch); 
 }
 
 /**********************************************************************/
@@ -138,7 +156,7 @@ PangoScriptIter *
 pango_script_iter_new (const char *text,
 		       int         length)
 {
-  PangoScriptIter *iter = g_new (PangoScriptIter, 1);
+  PangoScriptIter *iter = g_slice_new (PangoScriptIter);
 
   iter->text_start = text;
   if (length >= 0)
@@ -168,7 +186,7 @@ pango_script_iter_new (const char *text,
 void
 pango_script_iter_free (PangoScriptIter *iter)
 {
-  g_free (iter);
+  g_slice_free (PangoScriptIter, iter);
 }
 
 /**
@@ -251,11 +269,11 @@ get_pair_index (gunichar ch)
  * pango_script_iter_next:
  * @iter: a #PangoScriptIter
  * 
- * Advances a #PangoScriptIter to the next range. If the iter
+ * Advances a #PangoScriptIter to the next range. If @iter
  * is already at the end, it is left unchanged and %FALSE
  * is returned.
  * 
- * Return value: %TRUE if the iter was succesfully advanced.
+ * Return value: %TRUE if @iter was successfully advanced.
  *
  * Since: 1.4
  **/
@@ -270,15 +288,18 @@ pango_script_iter_next (PangoScriptIter *iter)
   start_sp = iter->paren_sp;
   iter->script_code = PANGO_SCRIPT_COMMON;
   iter->script_start = iter->script_end;
-  
+
   for (; iter->script_end < iter->text_end; iter->script_end = g_utf8_next_char (iter->script_end))
     {
       gunichar ch = g_utf8_get_char (iter->script_end);
       PangoScript sc;
       int pair_index;
-
+      
       sc = pango_script_for_unichar (ch);
-      pair_index = get_pair_index (ch);
+      if (sc != PANGO_SCRIPT_COMMON)
+	pair_index = -1;
+      else
+	pair_index = get_pair_index (ch);
 
       /*
        * Paired character handling:
@@ -398,7 +419,7 @@ script_for_lang_compare (gconstpointer key,
 
 /**
  * pango_language_includes_script:
- * @language: a PangoLanguage
+ * @language: a #PangoLanguage
  * @script: a #PangoScript
  * 
  * Determines if @script is one of the scripts used to
@@ -422,7 +443,7 @@ pango_language_includes_script (PangoLanguage *language,
 				PangoScript    script)
 {
   PangoScriptForLang *script_for_lang;
-  int j;
+  unsigned int j;
 
   g_return_val_if_fail (language != NULL, FALSE);
 
@@ -456,7 +477,7 @@ pango_language_includes_script (PangoLanguage *language,
  * representative of that script. This will usually be the
  * most widely spoken or used language written in that script:
  * for instance, the sample language for %PANGO_SCRIPT_CYRILLIC
- * is <literal>ru</literal> (Russian), the sample lanugage
+ * is <literal>ru</literal> (Russian), the sample language
  * for %PANGO_SCRIPT_ARABIC is <literal>ar</literal>.
  *
  * For some
@@ -557,12 +578,19 @@ pango_script_get_sample_language (PangoScript script)
     /* Syloti Nagri is used for Sylheti, no ISO 639 code */
     "",    /* PANGO_SCRIPT_SYLOTI_NAGRI */
     "peo", /* PANGO_SCRIPT_OLD_PERSIAN */
-    "",    /*  PANGO_SCRIPT_KHAROSHTHI */
+    "",    /* PANGO_SCRIPT_KHAROSHTHI */
+
+    "",    /* PANGO_SCRIPT_UNKNOWN */
+    "",    /* PANGO_SCRIPT_BALINESE */
+    "",    /* PANGO_SCRIPT_CUNEIFORM */
+    "",    /* PANGO_SCRIPT_PHOENICIAN */
+    "",    /* PANGO_SCRIPT_PHAGS_PA */
+    "nqo"  /* PANGO_SCRIPT_NKO */
   };
   const char *sample_language;
   
   g_return_val_if_fail (script >= 0, NULL);
-  g_return_val_if_fail (script < G_N_ELEMENTS (sample_languages), NULL);
+  g_return_val_if_fail ((guint)script < G_N_ELEMENTS (sample_languages), NULL);
   
   sample_language = sample_languages[script];
 
