@@ -1,5 +1,5 @@
 /* Pango
- * pangatsui-fontmap.c
+ * pangoatsui-fontmap.c
  *
  * Copyright (C) 2000-2003 Red Hat, Inc.
  * Copyright (C) 2005 Imendio AB
@@ -545,7 +545,7 @@ pango_atsui_font_map_load_font (PangoFontMap               *fontmap,
 
   size = pango_font_description_get_size (description);
 
-  if (size <= 0)
+  if (size < 0)
     return NULL;
 
   name = g_utf8_casefold (pango_font_description_get_family (description), -1);
@@ -578,6 +578,9 @@ pango_atsui_font_map_load_font (PangoFontMap               *fontmap,
 	    }
 	}
       
+      if (best_desc == NULL || best_face == NULL)
+        return NULL;
+
       pango_font_description_set_size (best_desc, size);
 
       best_font = pango_atsui_font_map_lookup (atsuifontmap, context, best_desc, best_face->postscript_name);
