@@ -30,6 +30,8 @@ G_BEGIN_DECLS
 
 #include <X11/Xlib.h>
 
+#ifndef PANGO_DISABLE_DEPRECATED
+
 #define PANGO_RENDER_TYPE_X "PangoRenderX"
 
 typedef GC (*PangoGetGCFunc) (PangoContext *context, PangoColor *color, GC base_gc);
@@ -122,6 +124,8 @@ gboolean pango_x_apply_ligatures (PangoFont     *font,
                                   int           *n_glyphs,
                                   int          **clusters);
 
+#endif /* PANGO_DISABLE_DEPRECATED */
+
 G_END_DECLS
 
 #endif /* __PANGOX_H__ */
